==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/EditorDefinitionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { EditorDefinitionDescription } from "./EditorDefinitionDescription";
/**
 * @hidden
 */
export let EditorDefinitionDescriptionMetadata = /*@__PURE__*/ (() => {
    class EditorDefinitionDescriptionMetadata extends Base {
        static b(a) {
            if (EditorDefinitionDescriptionMetadata.a == null) {
                EditorDefinitionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                EditorDefinitionDescriptionMetadata.c(EditorDefinitionDescriptionMetadata.a);
            }
            if (a.j(EditorDefinitionDescriptionMetadata.a)) {
                return;
            }
            a.y(EditorDefinitionDescriptionMetadata.a);
        }
        static c(a) {
            DefinitionBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            EditorDefinitionDescriptionMetadata.b(a);
            a.aa("EditorDefinition", () => new EditorDefinitionDescription());
            a.z("EditorDefinition", EditorDefinitionDescriptionMetadata.a);
        }
    }
    EditorDefinitionDescriptionMetadata.$t = /*@__PURE__*/ markType(EditorDefinitionDescriptionMetadata, 'EditorDefinitionDescriptionMetadata');
    EditorDefinitionDescriptionMetadata.a = null;
    return EditorDefinitionDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/EditorDefinitionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { EditorDefinitionDescription } from "./EditorDefinitionDescription";
/**
 * @hidden
 */
export let EditorDefinitionDescriptionMetadata = /*@__PURE__*/ (() => {
    class EditorDefinitionDescriptionMetadata extends Base {
        static b(a) {
            if (EditorDefinitionDescriptionMetadata.a == null) {
                EditorDefinitionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                EditorDefinitionDescriptionMetadata.c(EditorDefinitionDescriptionMetadata.a);
            }
            if (a.k(EditorDefinitionDescriptionMetadata.a)) {
                return;
            }
            a.aa(EditorDefinitionDescriptionMetadata.a);
        }
        static c(a) {
            DefinitionBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            EditorDefinitionDescriptionMetadata.b(a);
            a.ac("EditorDefinition", () => new EditorDefinitionDescription());
            a.ab("EditorDefinition", EditorDefinitionDescriptionMetadata.a);
        }
    }
    EditorDefinitionDescriptionMetadata.$t = /*@__PURE__*/ markType(EditorDefinitionDescriptionMetadata, 'EditorDefinitionDescriptionMetadata');
    EditorDefinitionDescriptionMetadata.a = null;
    return EditorDefinitionDescriptionMetadata;
})();
